@@ -1,14 +1,10 @@
 package Test::DBIC::Schema::Connector;
-BEGIN {
-  $Test::DBIC::Schema::Connector::AUTHORITY = 'cpan:GETTY';
-}
-BEGIN {
-  $Test::DBIC::Schema::Connector::VERSION = '0.002';
-}
+our $AUTHORITY = 'cpan:GETTY';
+$Test::DBIC::Schema::Connector::VERSION = '0.003';
 # ABSTRACT: Generate an instance of a DBIx::Class::Schema as test database
 use Exporter::Lite;
 
-@EXPORT = qw(test_dbic_schema_connect);
+@EXPORT = qw( test_dbic_schema_connect );
 
 use strict;
 use warnings;
@@ -48,8 +44,8 @@ sub test_dbic_schema_connect {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -58,7 +54,7 @@ Test::DBIC::Schema::Connector - Generate an instance of a DBIx::Class::Schema as
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -71,9 +67,9 @@ version 0.002
   # MYSCHEMA_PASS will be used as password if given
 
   my $schema = test_dbic_schema_connect('MySchema',{
-	env_prefix => 'I_LOVE',
-	user => 'peter',
-	env_pass => 'I_HATE_PASS',
+    env_prefix => 'I_LOVE',
+    user => 'peter',
+    env_pass => 'I_HATE_PASS',
   });
   
   # I_LOVE_DSN will be used as DSN if given
@@ -152,5 +148,15 @@ This software is copyright (c) 2011 by Raudssus Social Software.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut
+=head1 AUTHOR
 
+Torsten Raudssus <torsten@raudss.us> L<http://raudss.us/>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Raudssus Social Software.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
